Struct partiql_value::NullSortedValue
source · pub struct NullSortedValue<'a, const NULLS_FIRST: bool, T>(pub &'a T);Expand description
A wrapper on [T] that specifies if a null or missing value should be ordered before
([NULLS_FIRST] is true) or after ([NULLS_FIRST] is false) other values.
Tuple Fields
0: &'a TTrait Implementations
sourceimpl<'a, const NULLS_FIRST: bool> Ord for NullSortedValue<'a, NULLS_FIRST, Bag>
impl<'a, const NULLS_FIRST: bool> Ord for NullSortedValue<'a, NULLS_FIRST, Bag>
sourceimpl<'a, const NULLS_FIRST: bool> Ord for NullSortedValue<'a, NULLS_FIRST, List>
impl<'a, const NULLS_FIRST: bool> Ord for NullSortedValue<'a, NULLS_FIRST, List>
sourceimpl<'a, const NULLS_FIRST: bool> Ord for NullSortedValue<'a, NULLS_FIRST, Tuple>
impl<'a, const NULLS_FIRST: bool> Ord for NullSortedValue<'a, NULLS_FIRST, Tuple>
sourceimpl<'a, const NULLS_FIRST: bool> Ord for NullSortedValue<'a, NULLS_FIRST, Value>
impl<'a, const NULLS_FIRST: bool> Ord for NullSortedValue<'a, NULLS_FIRST, Value>
sourceimpl<'a, const NULLS_FIRST: bool, T: PartialEq> PartialEq for NullSortedValue<'a, NULLS_FIRST, T>
impl<'a, const NULLS_FIRST: bool, T: PartialEq> PartialEq for NullSortedValue<'a, NULLS_FIRST, T>
sourcefn eq(&self, other: &NullSortedValue<'a, NULLS_FIRST, T>) -> bool
fn eq(&self, other: &NullSortedValue<'a, NULLS_FIRST, T>) -> bool
Tests for
self and other values to be equal, and is used by ==.sourceimpl<'a, const NULLS_FIRST: bool, T> PartialOrd for NullSortedValue<'a, NULLS_FIRST, T>
impl<'a, const NULLS_FIRST: bool, T> PartialOrd for NullSortedValue<'a, NULLS_FIRST, T>
impl<'a, const NULLS_FIRST: bool, T: Eq> Eq for NullSortedValue<'a, NULLS_FIRST, T>
impl<'a, const NULLS_FIRST: bool, T> StructuralPartialEq for NullSortedValue<'a, NULLS_FIRST, T>